@@ -55,8 +55,9 @@ class SearchWindow(QMainWindow, Ui_SearchWindow):
 
         self.results = []
         self.textLabelLogo.setPixmap(pixmap)
+        self.lineEditSearch.setFocus()
 
-    def on_pushButtonSearch_released(self):
+    def doSearch(self):
         self.results = []
         self.resultsWindow.listWidgetResults.clear()
         self.resultsWindow.history = []
@@ -73,6 +74,12 @@ class SearchWindow(QMainWindow, Ui_SearchWindow):
         except:
                pass
         self.resultsWindow.show()
+    
+    def on_pushButtonSearch_released(self):
+        self.doSearch()
+
+    def on_lineEditSearch_returnPressed(self):
+        self.doSearch()
 
 class ResultsWindow(QMainWindow, Ui_ResultsWindow):
 
@@ -111,6 +118,8 @@ class ResultsWindow(QMainWindow, Ui_ResultsWindow):
             else:
                 if os.path.isfile('/opt/kmplayer/bin/kmplayer'):
                     os.system('/opt/kmplayer/bin/kmplayer %s &' % ui.results[self.index].get('URL'))
+                elif os.path.isfile('/usr/bin/kmplayer'):
+                    os.system('/usr/bin/kmplayer %s &' % ui.results[self.index].get('URL'))
                 elif os.path.isfile('/Applications/VLC.app/Contents/MacOS/VLC'):
                     os.system('/Applications/VLC.app/Contents/MacOS/VLC %s &' % ui.results[self.index].get('URL'))
                 elif os.path.isfile('c:/program files/VideoLAN/vlc/vlc.exe'):
